@@ -13,16 +13,14 @@ nice to have:
 import itertools
 import typing as t
 
+from buvar.components import ComponentLookupError
+
 missing = object()
 
 
 T = t.TypeVar("T")
 
 
-class ComponentLookupError(Exception):
-    pass
-
-
 class Components:
     """A component registry holds certain items identified by a
     namespace discriminator."""
