@@ -1,11 +1,11 @@
+import dataclasses as dc
 import functools
 import logging
 import logging.config
-from os import getpid
 import sys
 import typing
+from os import getpid
 
-import attr
 import structlog
 from structlog.processors import JSONRenderer
 
@@ -28,7 +28,9 @@ try:
     json_dumps_inner = functools.partial(
         orjson.dumps, option=orjson.OPT_NAIVE_UTC | orjson.OPT_NON_STR_KEYS
     )
-    json_dumps = lambda *arg, **kwargs: json_dumps_inner(*arg, **kwargs).decode("utf-8")
+
+    def json_dumps(*arg, **kwargs):
+        return json_dumps_inner(*arg, **kwargs).decode("utf-8")
 except ImportError:
     import json
 
@@ -54,7 +56,7 @@ DEFAULT_LOGGING_LEVEL = logging.getLevelName(logging.WARNING)
 timestamper = structlog.processors.TimeStamper(fmt="ISO", utc=True)
 
 
-@attr.s(auto_attribs=True, kw_only=True)
+@dc.dataclass
 class LogConfig:
     tty: bool = sys.stdout.isatty()
     level: typing.Union[int, str] = logging.DEBUG
@@ -158,7 +160,6 @@ def setup_logging(**kwargs):
 
 
 class ExtractLogExtra:  # noqa: R0903
-
     """Extract log record attributes to structlog event_dict."""
 
     def __init__(self, *attrs):
@@ -177,7 +178,6 @@ class ExtractLogExtra:  # noqa: R0903
 
 
 class StdioToLog:
-
     """Delegate sys.stdout to a logger."""
 
     def __init__(self, logger, log_level=logging.INFO):
