@@ -6,7 +6,6 @@ These tasks are then run until complete.
 A py:obj:`buvar.components.Components` context is stacked in way, that plugins
 share the same context, while tasks don't, but may access the plugin context.
 
-
     >>> loop = asyncio.get_event_loop()
     >>> state = {}
     >>> async def prepare(load: Loader):
@@ -26,14 +25,16 @@ share the same context, while tasks don't, but may access the plugin context.
     ['foo']
     >>> assert state == {'task': True}
 """
+
+# XXX FIXME doctest sometime shows log messages
 import asyncio
 import collections.abc
 import inspect
 import itertools
+import signal
 import sys
 import types
 import typing as t
-import signal
 
 import structlog
 
@@ -177,7 +178,7 @@ class Stage:
             .push()
         )
         # provide basic components
-        self.cancel = self.context.add(Cancel(loop=self.loop))
+        self.cancel = self.context.add(Cancel())
         self.teardown = self.context.add(Teardown())
         self.loader = self.context.add(Loader())
         self.signals = self.context.add((signals or Signals)(self))
@@ -244,29 +245,24 @@ async def run(tasks, *, evt_cancel=None):
     if evt_cancel is None:
         evt_cancel = context.add(Cancel())
 
-    # we automatically elevate context stack for tasks
-    factory = context.set_task_factory()
-    try:
-        fut_tasks = asyncio.gather(*map(asyncio.create_task, tasks))
+    fut_tasks = asyncio.gather(*map(asyncio.create_task, tasks))
 
-        # stop staging if we finish in any way
-        fut_tasks.add_done_callback(lambda _: evt_cancel.set())
+    # stop staging if we finish in any way
+    fut_tasks.add_done_callback(lambda _: evt_cancel.set())
 
-        # wait for exit
-        await evt_cancel.wait()
+    # wait for exit
+    await evt_cancel.wait()
 
-        if not fut_tasks.done():
-            # we were explicitelly stopped by cancel event
-            fut_tasks.cancel()
-            try:
-                await fut_tasks
-            except asyncio.CancelledError:
-                # silence our shutdown
-                pass
-        else:
-            return fut_tasks.result()
-    finally:
-        factory.reset()
+    if not fut_tasks.done():
+        # we were explicitelly stopped by cancel event
+        fut_tasks.cancel()
+        try:
+            await fut_tasks
+        except asyncio.CancelledError:
+            # silence our shutdown
+            pass
+    else:
+        return fut_tasks.result()
 
 
 def collect_plugin_args(plugin):
